@@ -71,6 +71,9 @@ class PydanticGen(PythonGenerator):
 
     generatorname = Path(__file__).name
     generatorversion = PYTHON_GEN_VERSION
+    curie_regexp = (
+        r'^[a-zA-Z_]?[a-zA-Z_0-9.-]*:([A-Za-z0-9_][A-Za-z0-9_.-]*[A-Za-z0-9./\(\)\-><_:;]*)?$'
+    )
 
     def __init__(
         self,
@@ -167,13 +170,13 @@ from dataclasses import field
 from enum import Enum, unique
 from typing import Any, ClassVar, List, Optional, Union
 
-from pydantic import constr, validator
+from pydantic import constr, validator, Field
 from pydantic.dataclasses import dataclass
 
 LOG = logging.getLogger(__name__)
 
 metamodel_version = "{self.schema.metamodel_version}"
-curie_regexp = r'^[a-zA-Z_]?[a-zA-Z_0-9-]*:([A-Za-z0-9_][A-Za-z0-9_.-]*[A-Za-z0-9./\\(\\)\\-><_:;]*)?$'
+curie_regexp = r'{self.curie_regexp}'
 curie_pattern = re.compile(curie_regexp)
 
 # Type Aliases
@@ -521,7 +524,7 @@ valid_prefix = {{
         vars = []
 
         if not (cls.mixin or cls.abstract):
-            vars.append(f'_category: ClassVar[str] = "{camelcase(cls.name)}"')
+            vars.append(f'category: List[str] = Field(["biolink:{camelcase(cls.name)}"])')
 
         id_prefixes_fmt = ',\n'.join([f'\t\t"{prefix}"' for prefix in cls.id_prefixes])
 
@@ -694,14 +697,15 @@ Predicate = namedtuple(
     def __post_init__(self):
         # Initialize default categories if not set
         # by traversing the MRO chain
-        if not self.category:
-            self.category = list(
-                {
-                    f'biolink:{super_class._category}'
-                    for super_class in inspect.getmro(type(self))
-                    if hasattr(super_class, '_category')
-                }
-            )
+        pass
+        # if not self.category:
+        #     self.category = list(
+        #         {
+        #             f'biolink:{super_class._category}'
+        #             for super_class in inspect.getmro(type(self))
+        #             if hasattr(super_class, '_category')
+        #         }
+        #     )
         '''
 
     @staticmethod
@@ -745,7 +749,7 @@ def check_curie_prefix(cls, curie: Union[List, str, None]):
                         f"for a list of valid curie prefixes"
                     )
     elif curie:
-        prefix, local_id = curie.split(':')
+        prefix, local_id = curie.split(':', 1)
         if prefix not in valid_prefix:
             LOG.warning(f"{curie} prefix '{prefix}' not in curie map")
             if hasattr(cls, '_id_prefixes') and cls._id_prefixes:
