@@ -2,9 +2,9 @@ import re
 
 import pytest
 
-curie_regexp = re.compile(
-    r'^[a-zA-Z_]?[a-zA-Z_0-9-]*:([A-Za-z0-9_][A-Za-z0-9_.-]*[A-Za-z0-9./\(\)\-><_:;]*)?$'
-)
+from pydanticgen.pydanticgen import PydanticGen
+
+curie_regexp = re.compile(PydanticGen.curie_regexp)
 
 
 @pytest.mark.parametrize(
@@ -19,6 +19,7 @@ curie_regexp = re.compile(
         "D:1.1/a.bcd.1900.1.1",
         "DOI:10.10/06-11(22)33-1",
         "DOI:10.1002/(SICI)1097-0061(19980430)14:6<551::AID-YEA260>3.0.CO;2-Q",
+        "A.B:12345",
     ],
 )
 def test_valid_curie(curie):
